@@ -1,5 +1,8 @@
 package Log::Dispatch::Dir;
 
+our $DATE = '2015-12-16'; # DATE
+our $VERSION = '0.14'; # VERSION
+
 use 5.010001;
 use warnings;
 use strict;
@@ -10,9 +13,6 @@ use File::Slurp::Tiny qw(write_file);
 #use File::Stat qw(:stat); # doesn't work in all platforms?
 use Params::Validate qw(validate SCALAR CODEREF);
 use POSIX;
-use Taint::Util;
-
-our $VERSION = '0.12'; # VERSION
 
 Params::Validate::validation_options( allow_extra => 1 );
 
@@ -116,6 +116,7 @@ sub _resolve_pattern {
         return $default_ext unless $type;
         $type =~ s/[; ].*//; # only get the mime type
         my $ext = Media::Type::Simple::ext_from_type($type);
+        ($ext) = $ext =~ /(.+)/ if $ext; # untaint
         return $ext || $default_ext;
     };
 
@@ -162,7 +163,7 @@ sub _rotate {
     local *DH;
     opendir DH, $self->{dirname};
     while (my $e = readdir DH) {
-        untaint $e;
+        ($e) = $e =~ /(.*)/s; # untaint
         next if $e eq '.' || $e eq '..';
         my @st = stat "$d/$e";
         push @entries, {name => $e, age => ($now-$st[10]), size => $st[7]};
@@ -218,7 +219,7 @@ Log::Dispatch::Dir - Log messages to separate files in a directory, with rotate
 
 =head1 VERSION
 
-This document describes version 0.12 of Log::Dispatch::Dir (from Perl distribution Log-Dispatch-Dir), released on 2014-05-17.
+This document describes version 0.14 of Log::Dispatch::Dir (from Perl distribution Log-Dispatch-Dir), released on 2015-12-16.
 
 =head1 SYNOPSIS
 
@@ -411,7 +412,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Log-Dispat
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Log-Dispatch-Dir>.
+Source repository is at L<https://github.com/perlancar/perl-Log-Dispatch-Dir>.
 
 =head1 BUGS
 
@@ -423,11 +424,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
